package proxy.util;

import java.util.regex.Pattern;

import com.google.gson.JsonElement;
import com.google.gson.JsonParser;
import com.google.gson.JsonPrimitive;

public enum ChatColor {
	BLACK('0'),
	DARK_BLUE('1'),
	DARK_GREEN('2'),
	DARK_AQUA('3'),
	DARK_RED('4'),
	DARK_PURPLE('5'),
	GOLD('6'),
	GRAY('7'),
	DARK_GRAY('8'),
	BLUE('9'),
	GREEN('a'),
	AQUA('b'),
	RED('c'),
	LIGHT_PURPLE('d'),
	YELLOW('e'),
	WHITE('f'),
	OBFUSCATED('k'),
	BOLD('l'),
	STRIKETHROUGH('m'),
	UNDERLINE('n'),
	ITALIC('o'),
	RESET('r');

	private static final Pattern STRIP_PATTERN = Pattern.compile("(?i)" + String.valueOf('\u00a7') + "[0-9A-FK-OR]");

	private final String value;

	public static String strip(String str) {
		return str == null ? null : STRIP_PATTERN.matcher(str).replaceAll("");
	}
	
	public static String toJsonString(String text) {
		return new JsonPrimitive(text).toString();
	}
	
	public static String fromJsonString(String json) {
		JsonParser parser = new JsonParser();
		JsonElement elem;
		try {
			elem = parser.parse(json);
		}
		catch(Throwable t) {
			return null;
		}
		return elem.isJsonPrimitive() ? elem.getAsString() : null;
	}
	
	public static String getStringOrJson(String json) {
		String str = fromJsonString(json);
		return str == null ? "JSON:" + json : str;
	}

	private ChatColor(char code) {
		this.value = "\u00a7" + code;
	}

	public String toString() {
		return this.value;
	}
}
